##  Guidelines and Best Practices
  * Firstly, for the initial application portfolio assessment, you don’t necessarily need IT components when you start working with SAP LeanIX.
  * Model IT components if you, e.g., want to manage your providers (there is no direct link between application and provider, IT components need to be modeled to establish a relation to providers) or if you require information on the hosting location of your applications.
  * Model IT components if you require this information for a specific use case/ company strategy, e.g., cloud migration assessment (see example below).
  * Use the reference catalog to automate the creation of IT component and provider fact sheet subtypes for SaaS services (modeled as application in SAP LeanIX as described in [Application Modeling Guidelines](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page guides you on modeling applications, covering subtypes, best practices, versioning, hierarchies, and use cases. Avoid common antipatterns and gain valuable insights.")). Even if you are a SaaS-based organization, there might be use cases in the future where you need it; having them in the inventory doesn’t cost any harm and doesn’t add more effort (However, if you are 100% sure that you want to keep your inventory lean, you can deactivate the automated creation of IT components and providers in the reference catalog).
  * Describe cloud components first using the SaaS, IaaS, and PaaS fact sheet subtypes. Note that SaaS here relates to the hosting type of the application.
  * We recommend grouping IT components into tech categories to provide context to stakeholders unfamiliar with the product or service. The TBM Taxonomy can be used for that, as this is an established industry standard maintained by a renowned community.
  * IT components can also be imported via Excel (CMDB data export). This is only recommended in the case of a limited number of IT components. An import via the out-of-the-box integration with ServiceNow is also possible. To use the ServiceNow integration, you will need the SAP LeanIX Technology Risk and Compliance product in addition to SAP LeanIX Application Portfolio Management.
  * Make sure in this process to normalize the IT components to a high level before importing them to SAP LeanIX. By normalizing your IT components, we mean standardizing the names of IT components and also aggregating them to more meaningful items, e.g., aggregating all versions of a software to one major level version - which for any strategic planning is usually good enough. Currently, this step needs to be done manually, e.g., if you use a CMDB (Configuration Management Database), normalization of the versions and names is required – a service that SAP LeanIX does not offer at the moment. However, software records are automatically aggregated by SAP LeanIX if you are leveraging ServiceNow integration.
  * We recommend keeping the number of IT components low at the start of your SAP LeanIX journey. While it might be tempting to import everything - and possibly people in your organization suggesting that - you will have to maintain a lot more data and blow up any reports on IT components.
  * In general, you use IT components to model technology, not explicit instances of items. E.g., patch-level versions of software do not add any value to your EA work and strategic discussions with your stakeholders.
  * If you need to model instances because they add value (decide if you get business insights from that modeling or not), you will model those typically as an IT component. Some scenarios where this might be relevant are:
    * Varying hosting options (e.g., the same software is provisioned via Azure and via AWS).
    * Two business units host applications on various instances.
    * Instances for different purposes (test, production).
    * If it is the same version, it should be one fact sheet (as a rule of thumb).
    * When using the ServiceNow integration and there is a value in mapping “Application Services” from ServiceNow to SAP LeanIX, we recommend mapping them to the optional system fact sheets. To learn more, see [System Modeling Guidelines](https://help.sap.com/docs/leanix/ea/system-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Modeling guidelines, best practices, use cases, and recommendations for system fact sheets.").
  * If you want to model costs in SAP LeanIX, this can be done on the application fact sheet in SAP LeanIX, on the relation between the application and IT component (see this documentation for more information on [Cost Management](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD "Track and analyze IT costs across projects, applications, and infrastructure. Support strategic financial decisions in enterprise architecture with the right insights from reports.")).
